/**
 * Scriptable iOS Type Definitions
 *
 * @file Auto-generated abstract class definitions for Scriptable iOS
 * @version 1.0.1
 * @module scriptable-abstract
 * @generated 2024-12-17T17:04:07.426Z
 * @license MIT
 */
declare abstract class ScriptableObject {
    __props: Record<string, any>;
    static __className: string;
    __get(propName: string): any;
    __set(propName: string, value: any): void;
}
/**
 * Implementation class for Alert
 */
declare class AbsAlert extends ScriptableObject implements Partial<Alert> {
    static __className: string;
    /**
     * _Title displayed in the alert. Usually a short string._
     */
    get title(): string;
    set title(value: string);
    /**
     * _Detailed message displayed in the alert._
     */
    get message(): string;
    set message(value: string);
    /**
     * @param title string
     */
    addAction(_title: string): void;
    /**
     * @param title string
     */
    addDestructiveAction(_title: string): void;
    /**
     * @param title string
     */
    addCancelAction(_title: string): void;
    /**
     * @param placeholder string
     * @param text string
     * @returns {TextField}
     */
    addTextField(_placeholder?: string, _text?: string): TextField;
    /**
     * @param placeholder string
     * @param text string
     * @returns {TextField}
     */
    addSecureTextField(_placeholder?: string, _text?: string): TextField;
    /**
     * @param index number
     * @returns {string}
     */
    textFieldValue(_index: number): string;
    /**
     * @returns {Promise<number>}
     */
    present(): Promise<number>;
    /**
     * @returns {Promise<number>}
     */
    presentAlert(): Promise<number>;
    /**
     * @returns {Promise<number>}
     */
    presentSheet(): Promise<number>;
}
/**
 * Implementation class for Calendar
 */
declare class AbsCalendar extends ScriptableObject implements Partial<Calendar> {
    static __className: string;
    /**
     * _Calendar identifier._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Title of calendar._
     */
    get title(): string;
    set title(value: string);
    /**
     * _Whether the calendar is a subscribed calendar._
     */
    get isSubscribed(): boolean;
    set isSubscribed(value: boolean);
    /**
     * _Indicates whether items can be added, edited, and deleted in the calendar._
     */
    get allowsContentModifications(): boolean;
    set allowsContentModifications(value: boolean);
    /**
     * _Color of calendar._
     */
    get color(): Color;
    set color(value: Color);
    /**
     * @param availability "busy" | "free" | "tentative" | "unavailable"
     * @returns {boolean}
     */
    supportsAvailability(_availability: 'busy' | 'free' | 'tentative' | 'unavailable'): boolean;
    /**
     */
    save(): void;
    /**
     */
    remove(): void;
    /**
     * @returns {Promise<Calendar[]>}
     */
    static forReminders(): Promise<Calendar[]>;
    /**
     * @returns {Promise<Calendar[]>}
     */
    static forEvents(): Promise<Calendar[]>;
    /**
     * @param title string
     * @returns {Promise<Calendar>}
     */
    static forRemindersByTitle(_title: string): Promise<Calendar>;
    /**
     * @param title string
     * @returns {Promise<Calendar>}
     */
    static forEventsByTitle(_title: string): Promise<Calendar>;
    /**
     * @param title string
     * @returns {Promise<Calendar>}
     */
    static createForReminders(_title: string): Promise<Calendar>;
    /**
     * @param title string
     * @returns {Promise<Calendar>}
     */
    static findOrCreateForReminders(_title: string): Promise<Calendar>;
    /**
     * @returns {Promise<Calendar>}
     */
    static defaultForReminders(): Promise<Calendar>;
    /**
     * @returns {Promise<Calendar>}
     */
    static defaultForEvents(): Promise<Calendar>;
    /**
     * @param allowMultiple boolean
     * @returns {Promise<Calendar[]>}
     */
    static presentPicker(_allowMultiple?: boolean): Promise<Calendar[]>;
}
/**
 * Implementation class for CalendarEvent
 */
declare class AbsCalendarEvent extends ScriptableObject implements Partial<CalendarEvent> {
    static __className: string;
    /**
     * _Identifier of event._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Title of event._
     */
    get title(): string;
    set title(value: string);
    /**
     * _Location of event._
     */
    get location(): string;
    set location(value: string);
    /**
     * _Notes associated with event._
     */
    get notes(): string;
    set notes(value: string);
    /**
     * _Start date of event._
     */
    get startDate(): Date;
    set startDate(value: Date);
    /**
     * _End date of event._
     */
    get endDate(): Date;
    set endDate(value: Date);
    /**
     * _Whether the event is an all-day event._
     */
    get isAllDay(): boolean;
    set isAllDay(value: boolean);
    /**
     * _Attendees associated with the event._
     *
     * An array of objects on the following form:
     *
     * {
     * "isCurrentUser": false,
     * "name": "John Appleseed",
     * "status": "accepted",
     * "type": "person",
     * "role": "required"
     * }
     *
     * Note that the property is read-only since iOS does not expose API to modify the attendees of an event.
     */
    get attendees(): CalendarEvent.Attendees[];
    set attendees(value: CalendarEvent.Attendees[]);
    /**
     * _Availability during the event._
     *
     * Indicates how the event should be treated for scheduling purposes. The following values are supported:
     *
     * *   busy
     * *   free
     * *   tentative
     * *   unavailable
     *
     * Be aware that not all calendars support all of these availabilities and some calendars may not support availability at all. Use `Calendar.supportsAvailability()` to check if a
     * calendar supports a specific availability.
     *
     * @type {"busy" | "free" | "tentative" | "unavailable"}
     */
    get availability(): 'busy' | 'free' | 'tentative' | 'unavailable';
    set availability(value: 'busy' | 'free' | 'tentative' | 'unavailable');
    /**
     * _Time zone of event._
     *
     * Geopolitical region identifier that identifies the time zone, e.g. "Europe/Copenhagen", "America/New\_York" and "Asia/Tokyo".
     */
    get timeZone(): string;
    set timeZone(value: string);
    /**
     * _Calendar the event is stored in._
     */
    get calendar(): Calendar;
    set calendar(value: Calendar);
    /**
     * @param recurrenceRule RecurrenceRule
     */
    addRecurrenceRule(_recurrenceRule: RecurrenceRule): void;
    /**
     */
    removeAllRecurrenceRules(): void;
    /**
     */
    save(): void;
    /**
     */
    remove(): void;
    /**
     * @returns {Promise<CalendarEvent>}
     */
    presentEdit(): Promise<CalendarEvent>;
    /**
     * @returns {Promise<CalendarEvent>}
     */
    static presentCreate(): Promise<CalendarEvent>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static today(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static tomorrow(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static yesterday(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static thisWeek(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static nextWeek(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static lastWeek(_calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
    /**
     * @param startDate Date
     * @param endDate Date
     * @param calendars readonly Calendar[]
     * @returns {Promise<CalendarEvent[]>}
     */
    static between(_startDate: Date, _endDate: Date, _calendars?: readonly Calendar[]): Promise<CalendarEvent[]>;
}
/**
 * Implementation class for CallbackURL
 * @template T - extends string - defaults to string
 */
declare class AbsCallbackURL<T extends string = string> extends ScriptableObject implements Partial<CallbackURL<T>> {
    static __className: string;
    /**
     * @param name string
     * @param value string
     */
    addParameter(_name: string, _value: string): void;
    open(): Promise<T extends `shortcuts://x-callback-url/${string}` ? {
        result: string | number | boolean | null;
    } : Record<string, string | number | boolean | null>>;
    /**
     * @returns {string}
     */
    getURL(): string;
}
/**
 * Implementation class for Color
 */
declare class AbsColor extends ScriptableObject implements Partial<Color> {
    static __className: string;
    /**
     * _HEX representation._
     */
    get hex(): string;
    set hex(value: string);
    /**
     * _Amount of red in the color._
     */
    get red(): number;
    set red(value: number);
    /**
     * _Amount of green in the color._
     */
    get green(): number;
    set green(value: number);
    /**
     * _Amount of blue in the color._
     */
    get blue(): number;
    set blue(value: number);
    /**
     * _Alpha of the color._
     */
    get alpha(): number;
    set alpha(value: number);
    /**
     * @returns {Color}
     */
    static black(): Color;
    /**
     * @returns {Color}
     */
    static darkGray(): Color;
    /**
     * @returns {Color}
     */
    static lightGray(): Color;
    /**
     * @returns {Color}
     */
    static white(): Color;
    /**
     * @returns {Color}
     */
    static gray(): Color;
    /**
     * @returns {Color}
     */
    static red(): Color;
    /**
     * @returns {Color}
     */
    static green(): Color;
    /**
     * @returns {Color}
     */
    static blue(): Color;
    /**
     * @returns {Color}
     */
    static cyan(): Color;
    /**
     * @returns {Color}
     */
    static yellow(): Color;
    /**
     * @returns {Color}
     */
    static magenta(): Color;
    /**
     * @returns {Color}
     */
    static orange(): Color;
    /**
     * @returns {Color}
     */
    static purple(): Color;
    /**
     * @returns {Color}
     */
    static brown(): Color;
    /**
     * @returns {Color}
     */
    static clear(): Color;
    /**
     * @param lightColor Color
     * @param darkColor Color
     * @returns {Color}
     */
    static dynamic(_lightColor: Color, _darkColor: Color): Color;
}
/**
 * Implementation class for Contact
 */
declare class AbsContact extends ScriptableObject implements Partial<Contact> {
    static __className: string;
    /**
     * _Uniquely identifies the contact on the device._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Name prefix._
     */
    get namePrefix(): string;
    set namePrefix(value: string);
    /**
     * _Given name._
     */
    get givenName(): string;
    set givenName(value: string);
    /**
     * _Middle name._
     */
    get middleName(): string;
    set middleName(value: string);
    /**
     * _Family name._
     */
    get familyName(): string;
    set familyName(value: string);
    /**
     * _Nickname._
     */
    get nickname(): string;
    set nickname(value: string);
    /**
     * _Birthday._
     */
    get birthday(): Date;
    set birthday(value: Date);
    /**
     * _Profile picture._
     */
    get image(): Image;
    set image(value: Image);
    /**
     * _Email addresses._
     *
     * An array of objects on the following form:
     *
     * {
     * "identifier": "UUID-ABC-123",
     * "label": "Home",
     * "localizedLabel": "Home",
     * "value": "my@example.com"
     * }
     *
     * The identifier uniquely identifies the email address on this device. The label is a description of the email address and the value holds the email address itself.
     *
     * When updating this property, you must set the entire array of email addresses that you would like to store on the contact. Each value in the array must have the "value" key. The
     * other keys are optional.
     */
    get emailAddresses(): Contact.EmailAddresses[];
    set emailAddresses(value: Contact.EmailAddresses[]);
    /**
     * _Phone numbers._
     *
     * An array of objects on the following form:
     *
     * {
     * "identifier": "UUID-ABC-123",
     * "label": "Home",
     * "localizedLabel": "Home",
     * "value": "(111)234-5678"
     * }
     *
     * The identifier uniquely identifies the phone number on this device. The label is a description of the phone number and the value holds the phone number itself.
     *
     * When updating this property, you must set the entire array of phone numbers that you would like to store on the contact. Each value in the array must have the "value" key. The
     * other keys are optional.
     */
    get phoneNumbers(): Contact.PhoneNumbers[];
    set phoneNumbers(value: Contact.PhoneNumbers[]);
    /**
     * _Postal addresses._
     *
     * An array of objects on the following form:
     *
     * {
     * "identifier": "UUID-ABC-123",
     * "label": "Home",
     * "localizedLabel": "Home",
     * "street": "240  Terry Lane",
     * "city": "New York",
     * "state": "New York",
     * "postalCode": "10001",
     * "country": "United States of America"
     * }
     *
     * The identifier uniquely identifies the postal address on this device. The label is a description of the postal address.
     *
     * When updating this property, you must set the entire array of postal addresses that you would like to store on the contact. The "identifier" key is optional.
     */
    get postalAddresses(): Contact.PostalAddresses[];
    set postalAddresses(value: Contact.PostalAddresses[]);
    /**
     * _Social profiles._
     *
     * An array of objects on the following form:
     *
     * {
     * "identifier": "UUID-ABC-123",
     * "label": "Twitter",
     * "localizedLabel": "Twitter",
     * "service": "Twitter",
     * "url": "https://twitter.com/scriptableapp",
     * "userIdentifier": null,
     * "username": "scriptableapp"
     * }
     *
     * The identifier uniquely identifies the social profile on this device. The label is a description of the social profile, the service is the social profile's service name, the URL
     * contains a link to the social profile, the userIdentifier is the identifier of the social profile and the username is the name for the social profile.
     *
     * When updating this property, you must set the entire array of social profiles that you would like to store on the contact. The "identifier" key is optional.
     */
    get socialProfiles(): Contact.SocialProfiles[];
    set socialProfiles(value: Contact.SocialProfiles[]);
    /**
     * _Note for the contact._
     *
     * For security reasons, a contact's notes cannot be accessed in Siri, the Shortcuts app and in a notification.
     */
    get note(): string;
    set note(value: string);
    /**
     * _URL addresses._
     *
     * When updating this property, you must set the entire array of URL addresses that you would like to store on the contact. The "identifier" key is optional.
     *
     * @type {Array<{ [key: string]: string }>}
     */
    get urlAddresses(): Array<{
        [key: string]: string;
    }>;
    set urlAddresses(value: Array<{
        [key: string]: string;
    }>);
    /**
     * _Dates._
     *
     * When updating this property, you must set the entire array of dates that you would like to store on the contact. The "identifier" key is optional.
     *
     * @type {Array<{ [key: string]: any }>}
     */
    get dates(): Array<{
        [key: string]: any;
    }>;
    set dates(value: Array<{
        [key: string]: any;
    }>);
    /**
     * _Name of the organization associated with the contact._
     */
    get organizationName(): string;
    set organizationName(value: string);
    /**
     * _Name of the department associated with the contact._
     */
    get departmentName(): string;
    set departmentName(value: string);
    /**
     * _The contact's job title._
     */
    get jobTitle(): string;
    set jobTitle(value: string);
    /**
     * _Whether or not name prefix is available._
     *
     * The `namePrefix` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isNamePrefixAvailable(): boolean;
    set isNamePrefixAvailable(value: boolean);
    /**
     * _Whether or not given name is available._
     *
     * The `givenName` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isGiveNameAvailable(): boolean;
    set isGiveNameAvailable(value: boolean);
    /**
     * _Whether or not middle name is available._
     *
     * The `middleName` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isMiddleNameAvailable(): boolean;
    set isMiddleNameAvailable(value: boolean);
    /**
     * _Whether or not family name is available._
     *
     * The `familyName` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isFamilyNameAvailable(): boolean;
    set isFamilyNameAvailable(value: boolean);
    /**
     * _Whether or not nickname is available._
     *
     * The `nickname` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isNicknameAvailable(): boolean;
    set isNicknameAvailable(value: boolean);
    /**
     * _Whether or not birthday is available._
     *
     * The `birthday` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isBirthdayAvailable(): boolean;
    set isBirthdayAvailable(value: boolean);
    /**
     * _Whether or not email addresses are available._
     *
     * The `emailAddresses` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isEmailAddressesAvailable(): boolean;
    set isEmailAddressesAvailable(value: boolean);
    /**
     * _Whether or not phone numbers are available._
     *
     * The `phoneNumbers` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isPhoneNumbersAvailable(): boolean;
    set isPhoneNumbersAvailable(value: boolean);
    /**
     * _Whether or not postal addresses are available._
     *
     * The `postalAddresses` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isPostalAddressesAvailable(): boolean;
    set isPostalAddressesAvailable(value: boolean);
    /**
     * _Whether or not social profiles are available._
     *
     * The `socialProfiles` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isSocialProfilesAvailable(): boolean;
    set isSocialProfilesAvailable(value: boolean);
    /**
     * _Whether or not image is available._
     *
     * The `image` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isImageAvailable(): boolean;
    set isImageAvailable(value: boolean);
    /**
     * _Whether or not note is available._
     *
     * The `note` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isNoteAvailable(): boolean;
    set isNoteAvailable(value: boolean);
    /**
     * _Whether or not URL addresses are available._
     *
     * The `urlAddresses` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isURLAddressesAvailable(): boolean;
    set isURLAddressesAvailable(value: boolean);
    /**
     * _Whether or not organization name is available._
     *
     * The `organizationName` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isOrganizationNameAvailable(): boolean;
    set isOrganizationNameAvailable(value: boolean);
    /**
     * _Whether or not department name is available._
     *
     * The `departmentName` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isDepartmentNameAvailable(): boolean;
    set isDepartmentNameAvailable(value: boolean);
    /**
     * _Whether or not job title is available._
     *
     * The `jobTitle` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isJobTitleAvailable(): boolean;
    set isJobTitleAvailable(value: boolean);
    /**
     * _Whether or not dates are available._
     *
     * The `date` property may not be available if the container does not support it. In that case any value set on the property will be ignored.
     */
    get isDatesAvailable(): boolean;
    set isDatesAvailable(value: boolean);
    /**
     * @param containers readonly ContactsContainer[]
     * @returns {Promise<Contact[]>}
     */
    static all(_containers: readonly ContactsContainer[]): Promise<Contact[]>;
    /**
     * @param groups readonly ContactsGroup[]
     * @returns {Promise<Contact[]>}
     */
    static inGroups(_groups: readonly ContactsGroup[]): Promise<Contact[]>;
    /**
     * @param contact Contact
     * @param containerIdentifier string
     */
    static add(_contact: Contact, _containerIdentifier?: string): void;
    /**
     * @param contact Contact
     */
    static update(_contact: Contact): void;
    /**
     * @param contact Contact
     */
    static delete(_contact: Contact): void;
    /**
     * @returns {Promise<void>}
     */
    static persistChanges(): Promise<void>;
}
/**
 * Implementation class for ContactsContainer
 */
declare class AbsContactsContainer extends ScriptableObject implements Partial<ContactsContainer> {
    static __className: string;
    /**
     * _Identifier of the contacts container._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Name of the contacts container._
     */
    get name(): string;
    set name(value: string);
    /**
     * @returns {Promise<ContactsContainer>}
     */
    static default(): Promise<ContactsContainer>;
    /**
     * @returns {Promise<ContactsContainer[]>}
     */
    static all(): Promise<ContactsContainer[]>;
    /**
     * @param identifier string
     * @returns {Promise<ContactsContainer>}
     */
    static withIdentifier(_identifier: string): Promise<ContactsContainer>;
}
/**
 * Implementation class for ContactsGroup
 */
declare class AbsContactsGroup extends ScriptableObject implements Partial<ContactsGroup> {
    static __className: string;
    /**
     * _Identifier of the contacts group._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Name of the contacts group._
     */
    get name(): string;
    set name(value: string);
    /**
     * @param contact Contact
     */
    addMember(_contact: Contact): void;
    /**
     * @param contact Contact
     */
    removeMember(_contact: Contact): void;
    /**
     * @param containers readonly ContactsContainer[]
     * @returns {Promise<ContactsGroup[]>}
     */
    static all(_containers: readonly ContactsContainer[]): Promise<ContactsGroup[]>;
    /**
     * @param group ContactsGroup
     * @param containerIdentifier string
     */
    static add(_group: ContactsGroup, _containerIdentifier?: string): void;
    /**
     * @param group ContactsGroup
     */
    static update(_group: ContactsGroup): void;
    /**
     * @param group ContactsGroup
     */
    static delete(_group: ContactsGroup): void;
}
/**
 * Implementation class for Data
 */
declare class AbsData extends ScriptableObject implements Partial<Data> {
    static __className: string;
    /**
     * @returns {string}
     */
    toRawString(): string;
    /**
     * @returns {string}
     */
    toBase64String(): string;
    /**
     * @returns {number[]}
     */
    getBytes(): number[];
    /**
     * @param string string
     * @returns {Data}
     */
    static fromString(_string: string): Data;
    /**
     * @param filePath string
     * @returns {Data}
     */
    static fromFile(_filePath: string): Data;
    /**
     * @param base64String string
     * @returns {Data}
     */
    static fromBase64String(_base64String: string): Data;
    /**
     * @param image Image
     * @returns {Data}
     */
    static fromJPEG(_image: Image): Data;
    /**
     * @param image Image
     * @returns {Data}
     */
    static fromPNG(_image: Image): Data;
    /**
     * @param bytes readonly number[]
     * @returns {Data}
     */
    static fromBytes(_bytes: readonly number[]): Data;
}
/**
 * Implementation class for DateFormatter
 */
declare class AbsDateFormatter extends ScriptableObject implements Partial<DateFormatter> {
    static __className: string;
    /**
     * _Date format to be used by the formatter._
     *
     * Sets a fixed format to be used by the formatter. For example the date "2019-08-26 16:47" can be represented using the format "yyyy-MM-dd HH:mm".
     *
     * When converting dates to strings, it's advised to use some of the predefined formats for dates and times that can be applied using functions on the formatter, e.g.
     * `useMediumDateStyle()` and `useMediumTimeStyle()`.
     *
     * Year:
     *
     * *   `y`: Year with no padding. Example: "2019"
     * *   `yy`: Year with two zeros. Adds padding if necessary. Example: "19"
     * *   `yyyy`: Year with a minimum of four digits. Adds padding if necessary. Example: "2019"
     *
     * Quarter:
     *
     * *   `Q`: Quarter of the year. Example: "4"
     * *   `QQQQ`: Quarter spelled out. Example: "4th quarter"
     *
     * Month:
     *
     * *   `M`: Numeric month of the year. Example: "1"
     * *   `MM`: Numeric month of the year. Adds padding if necessary. Example: "01"
     * *   `MMM`: Shorthand name of the month. Example: "Jan"
     * *   `MMMM`: Full name of the month. Example: "January"
     * *   `MMMMM`: Narrow name of the month. Example: "J"
     *
     * Day:
     *
     * *   `d`: Day of the month. Example: "9"
     * *   `dd`: Day of the month. Adds padding if necessary. Example: "09"
     * *   `F`: Day of the week. Example: "3rd Friday in August"
     * *   `E`: Day of the week. Example: "Fri"
     * *   `EEEE`: Full name of the day. Example: "Friday"
     * *   `EEEEE`: Narrow day of the week. Example: "F"
     *
     * Hour:
     *
     * *   `h`: Hour on a 12-hour clock. Example: "9"
     * *   `hh`: Hour on a 12-hour clock. Adds padding if necessary. Example: "09"
     * *   `H`: Hour on a 24-hour clock. Example: "21"
     * *   `HH`: Hour on a 24-hour clock. Adds padding if necessary. Example: "21"
     * *   `a`: AM/PM for times on a 12-hour clock. Example: "PM"
     *
     * Minute:
     *
     * *   `m`: Minute. Example: "7"
     * *   `mm`: Minute. Adds padding if necessary. Example: "07"
     *
     * Second:
     *
     * *   `s`: Seconds. Example: "4"
     * *   `ss`: Seconds. Adds padding if necessary. Example: "04"
     * *   `SSS`: Milliseconds. Example: "384"
     *
     * Time zone:
     *
     * *   `zzz`: Three letter name of the time zone. Falls back to GMT-08:00 if the name is unknown. Example: "CST"
     * *   `zzzz`: Full name of the time zone. Falls back to GMT-08:00 if the name is unknown. Example: "Central Standard Time"
     * *   `Z`: Time zone in RFC 822 GMT format. Also matches a literal Z for Zulu (UTC) time. Example: "-0600"
     * *   `ZZZZ`: Time zone with abbreviation and offset. Example: "CST-06:00"
     * *   `ZZZZZ`: Time zone in ISO 8601 format. Example: "-06:00"
     *
     * A great resource for experimenting with date formats is nsdateformatter.com developed by Ben Scheirman.
     */
    get dateFormat(): string;
    set dateFormat(value: string);
    /**
     * _Locale to use when formatting._
     *
     * The locale should be specified using a string identifier, e.g. "en", "it" or "da". When no locale is set, the formatter will use the current locale of the device.
     */
    get locale(): string;
    set locale(value: string);
    /**
     * @param date Date
     * @returns {string}
     */
    string(_date: Date): string;
    /**
     * @param str string
     * @returns {Date}
     */
    date(_str: string): Date;
    /**
     */
    useNoDateStyle(): void;
    /**
     */
    useShortDateStyle(): void;
    /**
     */
    useMediumDateStyle(): void;
    /**
     */
    useLongDateStyle(): void;
    /**
     */
    useFullDateStyle(): void;
    /**
     */
    useNoTimeStyle(): void;
    /**
     */
    useShortTimeStyle(): void;
    /**
     */
    useMediumTimeStyle(): void;
    /**
     */
    useLongTimeStyle(): void;
    /**
     */
    useFullTimeStyle(): void;
}
/**
 * Implementation class for DatePicker
 */
declare class AbsDatePicker extends ScriptableObject implements Partial<DatePicker> {
    static __className: string;
    /**
     * _Minimum date that is selected in the picker._
     *
     * The minimum date, along with the maximum date, specifies the valid date range. The minimum and maximum dates are ignored if the minimum date is greater than the maximum date. The
     * dates are also ignored in countdown-timer mode.
     */
    get minimumDate(): Date;
    set minimumDate(value: Date);
    /**
     * _Maximum date that is selected in the picker._
     *
     * The maximum date, along with the minimum date, specifies the valid date range. The minimum and maximum dates are ignored if the minimum date is greater than the maximum date. The
     * dates are also ignored in countdown-timer mode.
     */
    get maximumDate(): Date;
    set maximumDate(value: Date);
    /**
     * _Countdown duration displayed by the date picker._
     *
     * Use this property to get and set the duration of a countdown when calling the `pickCountDownDuration()` function to present the picker. The default value is zero and the maximum
     * value is 23:59 (86,399 seconds).
     */
    get countdownDuration(): number;
    set countdownDuration(value: number);
    /**
     * _Interval at which the date picker displays minutes._
     *
     * Use the property to set the interval of the minute wheel. The default and minimum value is 1 and the maximum value is 30.
     */
    get minuteInterval(): number;
    set minuteInterval(value: number);
    /**
     * _The initially selected date._
     *
     * Use this property to specify the initially selected date and time when picking a date, a time or both using date picker. If no date is specified, the current date and time will be
     * selected initially.
     *
     * Be aware that this property does not hold the selected date after the date picker has been dismissed. The promises returned by `pickTime()`, `pickDate()` and `PickDateAndTime()`
     * carries the selected date.
     */
    get initialDate(): Date;
    set initialDate(value: Date);
    /**
     * @returns {Promise<Date>}
     */
    pickTime(): Promise<Date>;
    /**
     * @returns {Promise<Date>}
     */
    pickDate(): Promise<Date>;
    /**
     * @returns {Promise<Date>}
     */
    pickDateAndTime(): Promise<Date>;
    /**
     * @returns {Promise<number>}
     */
    pickCountdownDuration(): Promise<number>;
}
/**
 * Implementation class for DrawContext
 */
declare class AbsDrawContext extends ScriptableObject implements Partial<DrawContext> {
    static __className: string;
    /**
     * _Size of canvas._
     *
     * Specifies the size of the canvas on which you are drawing. The image returned by getImage() will have this exact size, except if respectScreenScale is true.
     */
    get size(): Size;
    set size(value: Size);
    /**
     * _Enable to respect the scale of the screen._
     *
     * Devices have a screen scale that is used to convert between the logical coordinate space and the device coordinate space. For example, retina screens have a screen scale of 2 or 3
     * meaning that one point in the logical coordinate space is represented by four or nine pixels. Respecting the screen scale will multiply the specified size of the canvas by the
     * screen scale. For example a canvas of size 200 by 200 will be 600 by 600 when the image is rendered on a retina screen with a screen scale of 3. When respecting the screen scale is
     * disabled, you may experience that your images looks blurry because essentially the size you have specified will be stretched when rendered on the screen. Default is false.
     */
    get respectScreenScale(): boolean;
    set respectScreenScale(value: boolean);
    /**
     * _Determines whether the context is opaque._
     *
     * When enabled your image will be rendered opaque. Default is true.
     */
    get opaque(): boolean;
    set opaque(value: boolean);
    /**
     * @returns {Image}
     */
    getImage(): Image;
    /**
     * @param image Image
     * @param rect Rect
     */
    drawImageInRect(_image: Image, _rect: Rect): void;
    /**
     * @param image Image
     * @param point Point
     */
    drawImageAtPoint(_image: Image, _point: Point): void;
    /**
     * @param color Color
     */
    setFillColor(_color: Color): void;
    /**
     * @param color Color
     */
    setStrokeColor(_color: Color): void;
    /**
     * @param width number
     */
    setLineWidth(_width: number): void;
    /**
     * @param rect Rect
     */
    fill(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    fillRect(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    fillEllipse(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    stroke(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    strokeRect(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    strokeEllipse(_rect: Rect): void;
    /**
     * @param path Path
     */
    addPath(_path: Path): void;
    /**
     */
    strokePath(): void;
    /**
     */
    fillPath(): void;
    /**
     * @param text string
     * @param pos Point
     */
    drawText(_text: string, _pos: Point): void;
    /**
     * @param text string
     * @param rect Rect
     */
    drawTextInRect(_text: string, _rect: Rect): void;
    /**
     * @param font Font
     */
    setFont(_font: Font): void;
    /**
     * @param color Color
     */
    setTextColor(_color: Color): void;
    /**
     */
    setTextAlignedLeft(): void;
    /**
     */
    setTextAlignedCenter(): void;
    /**
     */
    setTextAlignedRight(): void;
}
/**
 * Implementation class for FileManager
 */
declare class AbsFileManager extends ScriptableObject implements Partial<FileManager> {
    static __className: string;
    /**
     * @param filePath string
     * @returns {Data}
     */
    read(_filePath: string): Data;
    /**
     * @param filePath string
     * @returns {string}
     */
    readString(_filePath: string): string;
    /**
     * @param filePath string
     * @returns {Image}
     */
    readImage(_filePath: string): Image;
    /**
     * @param filePath string
     * @param content Data
     */
    write(_filePath: string, _content: Data): void;
    /**
     * @param filePath string
     * @param content string
     */
    writeString(_filePath: string, _content: string): void;
    /**
     * @param filePath string
     * @param image Image
     */
    writeImage(_filePath: string, _image: Image): void;
    /**
     * @param filePath string
     */
    remove(_filePath: string): void;
    /**
     * @param sourceFilePath string
     * @param destinationFilePath string
     */
    move(_sourceFilePath: string, _destinationFilePath: string): void;
    /**
     * @param sourceFilePath string
     * @param destinationFilePath string
     */
    copy(_sourceFilePath: string, _destinationFilePath: string): void;
    /**
     * @param filePath string
     * @returns {boolean}
     */
    fileExists(_filePath: string): boolean;
    /**
     * @param path string
     * @returns {boolean}
     */
    isDirectory(_path: string): boolean;
    /**
     * @param path string
     * @param intermediateDirectories boolean
     */
    createDirectory(_path: string, _intermediateDirectories?: boolean): void;
    /**
     * @returns {string}
     */
    temporaryDirectory(): string;
    /**
     * @returns {string}
     */
    cacheDirectory(): string;
    /**
     * @returns {string}
     */
    documentsDirectory(): string;
    /**
     * @returns {string}
     */
    libraryDirectory(): string;
    /**
     * @param lhsPath string
     * @param rhsPath string
     * @returns {string}
     */
    joinPath(_lhsPath: string, _rhsPath: string): string;
    /**
     * @param filePath string
     * @returns {string[]}
     */
    allTags(_filePath: string): string[];
    /**
     * @param filePath string
     * @param tag string
     */
    addTag(_filePath: string, _tag: string): void;
    /**
     * @param filePath string
     * @param tag string
     */
    removeTag(_filePath: string, _tag: string): void;
    /**
     * @param filePath string
     * @param name string
     * @returns {string}
     */
    readExtendedAttribute(_filePath: string, _name: string): string;
    /**
     * @param filePath string
     * @param value string
     * @param name string
     */
    writeExtendedAttribute(_filePath: string, _value: string, _name: string): void;
    /**
     * @param filePath string
     * @param name string
     */
    removeExtendedAttribute(_filePath: string, _name: string): void;
    /**
     * @param filePath string
     * @returns {string[]}
     */
    allExtendedAttributes(_filePath: string): string[];
    /**
     * @param filePath string
     * @returns {string}
     */
    getUTI(_filePath: string): string;
    /**
     * @param directoryPath string
     * @returns {string[]}
     */
    listContents(_directoryPath: string): string[];
    /**
     * @param filePath string
     * @param includeFileExtension boolean
     * @returns {string}
     */
    fileName(_filePath: string, _includeFileExtension?: boolean): string;
    /**
     * @param filePath string
     * @returns {string}
     */
    fileExtension(_filePath: string): string;
    /**
     * @param name string
     * @returns {string}
     */
    bookmarkedPath(_name: string): string;
    /**
     * @param name string
     * @returns {boolean}
     */
    bookmarkExists(_name: string): boolean;
    /**
     * @param filePath string
     * @returns {Promise<void>}
     */
    downloadFileFromiCloud(_filePath: string): Promise<void>;
    /**
     * @param filePath string
     * @returns {boolean}
     */
    isFileStoredIniCloud(_filePath: string): boolean;
    /**
     * @param filePath string
     * @returns {boolean}
     */
    isFileDownloaded(_filePath: string): boolean;
    /**
     * @param filePath string
     * @returns {Date}
     */
    creationDate(_filePath: string): Date;
    /**
     * @param filePath string
     * @returns {Date}
     */
    modificationDate(_filePath: string): Date;
    /**
     * @param filePath string
     * @returns {number}
     */
    fileSize(_filePath: string): number;
    /**
     * @returns {FileManager.AllFileBookmarks[]}
     */
    allFileBookmarks(): FileManager.AllFileBookmarks[];
    /**
     * @returns {FileManager}
     */
    static local(): FileManager;
    /**
     * @returns {FileManager}
     */
    static iCloud(): FileManager;
}
/**
 * Implementation class for Font
 */
declare class AbsFont extends ScriptableObject implements Partial<Font> {
    static __className: string;
    /**
     * @returns {Font}
     */
    static largeTitle(): Font;
    /**
     * @returns {Font}
     */
    static title1(): Font;
    /**
     * @returns {Font}
     */
    static title2(): Font;
    /**
     * @returns {Font}
     */
    static title3(): Font;
    /**
     * @returns {Font}
     */
    static headline(): Font;
    /**
     * @returns {Font}
     */
    static subheadline(): Font;
    /**
     * @returns {Font}
     */
    static body(): Font;
    /**
     * @returns {Font}
     */
    static callout(): Font;
    /**
     * @returns {Font}
     */
    static footnote(): Font;
    /**
     * @returns {Font}
     */
    static caption1(): Font;
    /**
     * @returns {Font}
     */
    static caption2(): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static systemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static ultraLightSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static thinSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static lightSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static regularSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static mediumSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static semiboldSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static boldSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static heavySystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static blackSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static italicSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static ultraLightMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static thinMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static lightMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static regularMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static mediumMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static semiboldMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static boldMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static heavyMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static blackMonospacedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static ultraLightRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static thinRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static lightRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static regularRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static mediumRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static semiboldRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static boldRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static heavyRoundedSystemFont(_size: number): Font;
    /**
     * @param size number
     * @returns {Font}
     */
    static blackRoundedSystemFont(_size: number): Font;
}
/**
 * Implementation class for Image
 */
declare class AbsImage extends ScriptableObject implements Partial<Image> {
    static __className: string;
    /**
     * _Size of the image in pixels._
     */
    get size(): Size;
    set size(value: Size);
    /**
     * @param filePath string
     * @returns {Image}
     */
    static fromFile(_filePath: string): Image;
    /**
     * @param data Data
     * @returns {Image}
     */
    static fromData(_data: Data): Image;
}
/**
 * Implementation class for LinearGradient
 */
declare class AbsLinearGradient extends ScriptableObject implements Partial<LinearGradient> {
    static __className: string;
    /**
     * _Colors of the gradient._
     *
     * The array of colors should include the same amount of elements as the gradients `locations` property.
     */
    get colors(): Color[];
    set colors(value: Color[]);
    /**
     * _Locations of each color._
     *
     * Each location should be a value in the range of 0 to 1 and indicates the location of each color in the gradients `colors` array.
     *
     * The array of locations should include the same amount of elements as the gradients `colors` property.
     */
    get locations(): number[];
    set locations(value: number[]);
    /**
     * _Point to start the gradient._
     *
     * The normalized starting point of the gradient. The `endPoint` and `startPoint` together controls the direction of the gradient. The X and Y component should each range from 0 to 1.
     * Defaults to (0, 1).
     */
    get startPoint(): Point;
    set startPoint(value: Point);
    /**
     * _Point to end the gradient._
     *
     * The normalized ending point of the gradient. The `endPoint` and `startPoint` together controls the direction of the gradient. The X and Y component should each range from 0 to 1.
     * Defaults to (0, 1).
     */
    get endPoint(): Point;
    set endPoint(value: Point);
}
/**
 * Implementation class for ListWidget
 */
declare class AbsListWidget extends ScriptableObject implements Partial<ListWidget> {
    static __className: string;
    /**
     * _Background color of the widget._
     *
     * Defaults to a solid color in widgets placed on the Home Screen and a transparent color placed on the Lock Screen.
     */
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    /**
     * _Background image._
     */
    get backgroundImage(): Image;
    set backgroundImage(value: Image);
    /**
     * _Background gradient._
     */
    get backgroundGradient(): LinearGradient;
    set backgroundGradient(value: LinearGradient);
    /**
     * _Whether to use an accessory widget background._
     *
     * Enable to add an adaptive background that provides a standard appearance based on the widget's environment. Defaults to false.
     *
     * This is only available starting from iOS 16.
     */
    get addAccessoryWidgetBackground(): boolean;
    set addAccessoryWidgetBackground(value: boolean);
    /**
     * _Spacing between elements._
     *
     * Specifies the spacing between elements in the widget. You can also use the `addSpacer()` function on the widget to add spacing between elements. Defaults to 0.
     */
    get spacing(): number;
    set spacing(value: number);
    /**
     * _URL to open._
     *
     * The URL will be opened when the widget is tapped. This will override any behavior defined in the configuration of the widget. E.g. if the widget is configured to run the script
     * when interacting with the widget but a URL is set the URL will take precedence.
     */
    get url(): string;
    set url(value: string);
    /**
     * _Earliest date to refresh the widget._
     *
     * The property indicates when the widget can be refreshed again. The widget will not be refreshed before the date has been reached. It is not guaranteed that the widget will refresh
     * at exactly the specified date.
     *
     * The refresh rate of a widget is partly up to iOS/iPadOS. For example, a widget may not refresh if the device is low on battery or the user is rarely looking at the widget.
     *
     * When the property is `null` the default refresh interval is used. Defaults to `null`.
     */
    get refreshAfterDate(): Date;
    set refreshAfterDate(value: Date);
    /**
     * @param text string
     * @returns {WidgetText}
     */
    addText(_text: string): WidgetText;
    /**
     * @param date Date
     * @returns {WidgetDate}
     */
    addDate(_date: Date): WidgetDate;
    /**
     * @param image Image
     * @returns {WidgetImage}
     */
    addImage(_image: Image): WidgetImage;
    /**
     * @param length number
     * @returns {WidgetSpacer}
     */
    addSpacer(_length?: number): WidgetSpacer;
    /**
     * @returns {WidgetStack}
     */
    addStack(): WidgetStack;
    /**
     * @param top number
     * @param leading number
     * @param bottom number
     * @param trailing number
     */
    setPadding(_top: number, _leading: number, _bottom: number, _trailing: number): void;
    /**
     */
    useDefaultPadding(): void;
    /**
     * @returns {Promise<void>}
     */
    presentSmall(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentMedium(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentLarge(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentExtraLarge(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentAccessoryInline(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentAccessoryCircular(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    presentAccessoryRectangular(): Promise<void>;
}
/**
 * Implementation class for Mail
 */
declare class AbsMail extends ScriptableObject implements Partial<Mail> {
    static __className: string;
    /**
     * _Recipients of the mail._
     *
     * Array of recipients to send the mail to. Elements in the array should be e-mail addresses. You will have a chance to modify this before the mail is sent.
     */
    get toRecipients(): string[];
    set toRecipients(value: string[]);
    /**
     * _Recipients to set CC on the mail._
     *
     * Array of recipients to set as CC on the mail. Elements in the array should be e-mail addresses. You will have a chance to modify this before the mail is sent.
     */
    get ccRecipients(): string[];
    set ccRecipients(value: string[]);
    /**
     * _Recipients to set BCC on the mail._
     *
     * Array of recipients to set as BCC on the mail. Elements in the array should be e-mail addresses. You will have a chance to modify this before the mail is sent.
     */
    get bccRecipients(): string[];
    set bccRecipients(value: string[]);
    /**
     * _Subject of the mail._
     *
     * Subject of the mail to send. You will have a chance to modify this before the mail is sent.
     */
    get subject(): string;
    set subject(value: string);
    /**
     * _Body of the mail._
     *
     * Body of the mail to send. You will have a chance to modify this before the mail is sent.
     */
    get body(): string;
    set body(value: string);
    /**
     * _Whether body is HTML._
     *
     * Set to true if the body of the mail is HTML. Defaults to false.
     */
    get isBodyHTML(): boolean;
    set isBodyHTML(value: boolean);
    /**
     * _Preferred email address to use in the from field._
     *
     * Sets the preferred email addressed to use when sending the mail. If no account with the preferred email address is set up, the default email address is used.
     */
    get preferredSendingEmailAddress(): string;
    set preferredSendingEmailAddress(value: string);
    /**
     * @returns {Promise<void>}
     */
    send(): Promise<void>;
    /**
     * @param image Image
     */
    addImageAttachment(_image: Image): void;
    /**
     * @param filePath string
     */
    addFileAttachment(_filePath: string): void;
    /**
     * @param data Data
     * @param mimeType string
     * @param filename string
     */
    addDataAttachment(_data: Data, _mimeType: string, _filename: string): void;
}
/**
 * Implementation class for Message
 */
declare class AbsMessage extends ScriptableObject implements Partial<Message> {
    static __className: string;
    /**
     * _Recipients of the message._
     *
     * Array of recipients to send the message to. Elements in the array should be phone numbers. You will have a chance to modify this before the message is sent.
     */
    get recipients(): string[];
    set recipients(value: string[]);
    /**
     * _Body of the message._
     *
     * Body of the message to send. You will have a chance to modify this before the message is sent.
     */
    get body(): string;
    set body(value: string);
    /**
     * @returns {Promise<void>}
     */
    send(): Promise<void>;
    /**
     * @param image Image
     */
    addImageAttachment(_image: Image): void;
    /**
     * @param filePath string
     */
    addFileAttachment(_filePath: string): void;
    /**
     * @param data Data
     * @param uti string
     * @param filename string
     */
    addDataAttachment(_data: Data, _uti: string, _filename: string): void;
}
/**
 * Implementation class for Notification
 */
declare class AbsNotification extends ScriptableObject implements Partial<Notification> {
    static __className: string;
    /**
     * _Identifier of the notification._
     *
     * To reschedule a notification, use the identifier of an existing notification.
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Title of the notification._
     */
    get title(): string;
    set title(value: string);
    /**
     * _Subtitle of the notification._
     */
    get subtitle(): string;
    set subtitle(value: string);
    /**
     * _Body of the notification._
     */
    get body(): string;
    set body(value: string);
    /**
     * _Preferred height of the notification._
     *
     * By default Scriptable attempts to determine an appropriate height for your notification. If you want to override the default behavior, you can specify a preferred content height.
     * The preferred content height is only used when running a script inside the notification, i.e. when `scriptName` is not null. iOS may limit the height of the notification in which
     * case the preferred content height is not guaranteed to be respected.
     */
    get preferredContentHeight(): number;
    set preferredContentHeight(value: number);
    /**
     * _Number to display in the app icon's badge._
     *
     * When the number is zero, no badge is displayed. When the number is greater than zero, the number is displayed in the app icon's badge. Setting the value to null, will leave the
     * badge unchanged. The default value is null.
     */
    get badge(): number;
    set badge(value: number);
    /**
     * _Identifier for grouping the notification._
     *
     * Notifications are grouped by the identifier on the Home Screen and in the Notification Center.
     */
    get threadIdentifier(): string;
    set threadIdentifier(value: string);
    /**
     * _Custom information._
     *
     * Store any custom information for the notification. This can be accessed from the `Notification.opened` property when a script is run from a notification.
     *
     * @type {{ [key: string]: any }}
     */
    get userInfo(): {
        [key: string]: any;
    };
    set userInfo(value: {
        [key: string]: any;
    });
    /**
   * _Sound of the notification._
   *
   * Set to null if you do not want any sound. Set to one of the following values if you want a sound.
   *
   * *   default
   * *   accept
   * *   alert
   * *   complete
   * *   event
   * *   failure
   * *   piano\_error
   * *   piano\_success
   * *   popup
   *
   * By default the notification is delivered with no sound.
   *
   * @type {| "default"
          | "accept"
          | "alert"
          | "complete"
          | "event"
          | "failure"
          | "piano_error"
          | "piano_success"
          | "popup"}
     */
    get sound(): 'default' | 'accept' | 'alert' | 'complete' | 'event' | 'failure' | 'piano_error' | 'piano_success' | 'popup';
    set sound(value: 'default' | 'accept' | 'alert' | 'complete' | 'event' | 'failure' | 'piano_error' | 'piano_success' | 'popup');
    /**
     * _URL to open when notification is tapped._
     *
     * The Scriptable application will open the URL when the notification is tapped. This can be a URL that uses Scriptables URL scheme, the URL scheme of another application or a website
     * URL.
     */
    get openURL(): string;
    set openURL(value: string);
    /**
     * _Delivery date of the notification._
     *
     * If the notification has already been delivered, for example because it was fetched using `Notification.allDelivered()`, the deliveryDate will be populated. Otherwise it will be
     * null.
     *
     * The property cannot be set. In order to specify a future delivery date for a notification, see the `setTriggerDate` function. For recurring notifications, see the `setDailyTrigger`
     * and `setWeeklyTrigger` functions.
     */
    get deliveryDate(): Date;
    set deliveryDate(value: Date);
    /**
     * _Next trigger date of the notification._
     *
     * The next trigger date is the point in time where the next notification will be delivered.
     *
     * The property cannot be set. In order to specify a future delivery date for a notification, see the `setTriggerDate` function. For recurring notifications, see the `setDailyTrigger`
     * and `setWeeklyTrigger` functions.
     */
    get nextTriggerDate(): Date;
    set nextTriggerDate(value: Date);
    /**
     * _Name of script to run in rich notification._
     *
     * When notification is force touched or long pressed, Scriptable can run a script inside the notification without opening the app. Set the `scriptName` to a name of an existing
     * script to run it inside the notification.
     */
    get scriptName(): string;
    set scriptName(value: string);
    /**
     * _Actions added to the notification._
     *
     * An array of objects on the following form:
     *
     * {
     * "title": "Open Website",
     * "url": "https://scriptable.app"
     * }
     *
     * To add a notification, use `Notification.addAction`.
     */
    get actions(): Notification.Actions;
    set actions(value: Notification.Actions);
    /**
     * @returns {Promise<void>}
     */
    schedule(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    remove(): Promise<void>;
    /**
     * @param date Date
     */
    setTriggerDate(_date: Date): void;
    /**
     * @param hour number
     * @param minute number
     * @param repeats boolean
     */
    setDailyTrigger(_hour: number, _minute: number, _repeats?: boolean): void;
    /**
     * @param weekday number
     * @param hour number
     * @param minute number
     * @param repeats boolean
     */
    setWeeklyTrigger(_weekday: number, _hour: number, _minute: number, _repeats?: boolean): void;
    /**
     * @param title string
     * @param url string
     * @param destructive boolean
     */
    addAction(_title: string, _url: string, _destructive?: boolean): void;
    /**
     * @returns {Promise<Notification[]>}
     */
    static allPending(): Promise<Notification[]>;
    /**
     * @returns {Promise<Notification[]>}
     */
    static allDelivered(): Promise<Notification[]>;
    /**
     * @returns {Promise<void>}
     */
    static removeAllPending(): Promise<void>;
    /**
     * @returns {Promise<void>}
     */
    static removeAllDelivered(): Promise<void>;
    /**
     * @param identifiers readonly string[]
     * @returns {Promise<void>}
     */
    static removePending(_identifiers: readonly string[]): Promise<void>;
    /**
     * @param identifiers readonly string[]
     * @returns {Promise<void>}
     */
    static removeDelivered(_identifiers: readonly string[]): Promise<void>;
    /**
     */
    static resetCurrent(): void;
}
/**
 * Implementation class for Path
 */
declare class AbsPath extends ScriptableObject implements Partial<Path> {
    static __className: string;
    /**
     * @param point Point
     */
    move(_point: Point): void;
    /**
     * @param point Point
     */
    addLine(_point: Point): void;
    /**
     * @param rect Rect
     */
    addRect(_rect: Rect): void;
    /**
     * @param rect Rect
     */
    addEllipse(_rect: Rect): void;
    /**
     * @param rect Rect
     * @param cornerWidth number
     * @param cornerHeight number
     */
    addRoundedRect(_rect: Rect, _cornerWidth: number, _cornerHeight: number): void;
    /**
     * @param point Point
     * @param control1 Point
     * @param control2 Point
     */
    addCurve(_point: Point, _control1: Point, _control2: Point): void;
    /**
     * @param point Point
     * @param control Point
     */
    addQuadCurve(_point: Point, _control: Point): void;
    /**
     * @param points readonly Point[]
     */
    addLines(_points: readonly Point[]): void;
    /**
     * @param rects readonly Rect[]
     */
    addRects(_rects: readonly Rect[]): void;
    /**
     */
    closeSubpath(): void;
}
/**
 * Implementation class for Point
 */
declare class AbsPoint extends ScriptableObject implements Partial<Point> {
    static __className: string;
    /**
     * _X value._
     */
    get x(): number;
    set x(value: number);
    /**
     * _Y value._
     */
    get y(): number;
    set y(value: number);
}
/**
 * Implementation class for Rect
 */
declare class AbsRect extends ScriptableObject implements Partial<Rect> {
    static __className: string;
    /**
     * _Minimum X value._
     *
     * The smallest x-coordinate in the rectangle.
     */
    get minX(): number;
    set minX(value: number);
    /**
     * _Minimum Y value._
     *
     * The smallest y-coordinate in the rectangle.
     */
    get minY(): number;
    set minY(value: number);
    /**
     * _Maximum X value._
     *
     * The greatest x-coordinate in the rectangle.
     */
    get maxX(): number;
    set maxX(value: number);
    /**
     * _Maximum Y value._
     *
     * The greatest y-coordinate in the rectangle.
     */
    get maxY(): number;
    set maxY(value: number);
    /**
     * _X value._
     *
     * The x-coordinate of the rectangle.
     */
    get x(): number;
    set x(value: number);
    /**
     * _Y value._
     *
     * The y-coordinate of the rectangle.
     */
    get y(): number;
    set y(value: number);
    /**
     * _Width of rectangle._
     *
     * The width of the rectangle.
     */
    get width(): number;
    set width(value: number);
    /**
     * _Height of rectangle._
     *
     * The height of the rectangle.
     */
    get height(): number;
    set height(value: number);
    /**
     * _Point that specifies the rectangles origin._
     *
     * The x- and y-coordinate that specifies the rectangles origin as a Point structure.
     */
    get origin(): Point;
    set origin(value: Point);
    /**
     * _Size of the rectangle._
     *
     * The width and height of the rectangle as a Size structure.
     */
    get size(): Size;
    set size(value: Size);
}
/**
 * Implementation class for RecurrenceRule
 */
declare class AbsRecurrenceRule extends ScriptableObject implements Partial<RecurrenceRule> {
    static __className: string;
    /**
     * @param interval number
     * @returns {RecurrenceRule}
     */
    static daily(_interval: number): RecurrenceRule;
    /**
     * @param interval number
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static dailyEndDate(_interval: number, _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static dailyOccurrenceCount(_interval: number, _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @returns {RecurrenceRule}
     */
    static weekly(_interval: number): RecurrenceRule;
    /**
     * @param interval number
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static weeklyEndDate(_interval: number, _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static weeklyOccurrenceCount(_interval: number, _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @returns {RecurrenceRule}
     */
    static monthly(_interval: number): RecurrenceRule;
    /**
     * @param interval number
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static monthlyEndDate(_interval: number, _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static monthlyOccurrenceCount(_interval: number, _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @returns {RecurrenceRule}
     */
    static yearly(_interval: number): RecurrenceRule;
    /**
     * @param interval number
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static yearlyEndDate(_interval: number, _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static yearlyOccurrenceCount(_interval: number, _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param setPositions readonly number[]
     * @returns {RecurrenceRule}
     */
    static complexWeekly(_interval: number, _daysOfTheWeek: readonly number[], _setPositions: readonly number[]): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param setPositions readonly number[]
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static complexWeeklyEndDate(_interval: number, _daysOfTheWeek: readonly number[], _setPositions: readonly number[], _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param setPositions readonly number[]
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static complexWeeklyOccurrenceCount(_interval: number, _daysOfTheWeek: readonly number[], _setPositions: readonly number[], _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param daysOfTheMonth readonly number[]
     * @param setPositions readonly number[]
     * @returns {RecurrenceRule}
     */
    static complexMonthly(_interval: number, _daysOfTheWeek: readonly number[], _daysOfTheMonth: readonly number[], _setPositions: readonly number[]): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param daysOfTheMonth readonly number[]
     * @param setPositions readonly number[]
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static complexMonthlyEndDate(_interval: number, _daysOfTheWeek: readonly number[], _daysOfTheMonth: readonly number[], _setPositions: readonly number[], _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param daysOfTheMonth readonly number[]
     * @param setPositions readonly number[]
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static complexMonthlyOccurrenceCount(_interval: number, _daysOfTheWeek: readonly number[], _daysOfTheMonth: readonly number[], _setPositions: readonly number[], _occurrenceCount: number): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param monthsOfTheYear readonly number[]
     * @param weeksOfTheYear readonly number[]
     * @param daysOfTheYear readonly number[]
     * @param setPositions readonly number[]
     * @returns {RecurrenceRule}
     */
    static complexYearly(_interval: number, _daysOfTheWeek: readonly number[], _monthsOfTheYear: readonly number[], _weeksOfTheYear: readonly number[], _daysOfTheYear: readonly number[], _setPositions: readonly number[]): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param monthsOfTheYear readonly number[]
     * @param weeksOfTheYear readonly number[]
     * @param daysOfTheYear readonly number[]
     * @param setPositions readonly number[]
     * @param endDate Date
     * @returns {RecurrenceRule}
     */
    static complexYearlyEndDate(_interval: number, _daysOfTheWeek: readonly number[], _monthsOfTheYear: readonly number[], _weeksOfTheYear: readonly number[], _daysOfTheYear: readonly number[], _setPositions: readonly number[], _endDate: Date): RecurrenceRule;
    /**
     * @param interval number
     * @param daysOfTheWeek readonly number[]
     * @param monthsOfTheYear readonly number[]
     * @param weeksOfTheYear readonly number[]
     * @param daysOfTheYear readonly number[]
     * @param setPositions readonly number[]
     * @param occurrenceCount number
     * @returns {RecurrenceRule}
     */
    static complexYearlyOccurrenceCount(_interval: number, _daysOfTheWeek: readonly number[], _monthsOfTheYear: readonly number[], _weeksOfTheYear: readonly number[], _daysOfTheYear: readonly number[], _setPositions: readonly number[], _occurrenceCount: number): RecurrenceRule;
}
/**
 * Implementation class for RelativeDateTimeFormatter
 */
declare class AbsRelativeDateTimeFormatter extends ScriptableObject implements Partial<RelativeDateTimeFormatter> {
    static __className: string;
    /**
     * _Locale to use when formatting._
     *
     * The locale should be specified using a string identifier, e.g. "en", "it" or "da". When no locale is set, the formatter will use the current locale of the device.
     */
    get locale(): string;
    set locale(value: string);
    /**
     * @param date Date
     * @param referenceDate Date
     * @returns {string}
     */
    string(_date: Date, _referenceDate: Date): string;
    /**
     */
    useNamedDateTimeStyle(): void;
    /**
     */
    useNumericDateTimeStyle(): void;
}
/**
 * Implementation class for Reminder
 */
declare class AbsReminder extends ScriptableObject implements Partial<Reminder> {
    static __className: string;
    /**
     * _Identifier of reminder._
     */
    get identifier(): string;
    set identifier(value: string);
    /**
     * _Title of reminder._
     */
    get title(): string;
    set title(value: string);
    /**
     * _Notes associated with reminder._
     */
    get notes(): string;
    set notes(value: string);
    /**
     * _Whether the reminder is completed._
     */
    get isCompleted(): boolean;
    set isCompleted(value: boolean);
    /**
     * _Whether the reminder is overdue._
     */
    get isOverdue(): boolean;
    set isOverdue(value: boolean);
    /**
     * _Priority of reminder._
     *
     * Specifies the prirority of the reminder with 0 representing an undefined priority, 1 the highest priority, and 9 the lowest priority.
     */
    get priority(): number;
    set priority(value: number);
    /**
     * _Due date of reminder._
     *
     * @type {Date | null}
     */
    get dueDate(): Date | null;
    set dueDate(value: Date | null);
    /**
     * _Whether the due date includes a time._
     *
     * When this is true, assignments to the `dueDate` property will include a time, when this is false, the time component of the date will be ignored. Defaults to true.
     */
    get dueDateIncludesTime(): boolean;
    set dueDateIncludesTime(value: boolean);
    /**
     * _Completion date of reminder._
     *
     * @type {Date | null}
     */
    get completionDate(): Date | null;
    set completionDate(value: Date | null);
    /**
     * _Creation date of reminder._
     *
     * @type {Date | null}
     */
    get creationDate(): Date | null;
    set creationDate(value: Date | null);
    /**
     * _Calendar the reminder is stored in._
     */
    get calendar(): Calendar;
    set calendar(value: Calendar);
    /**
     * @param recurrenceRule RecurrenceRule
     */
    addRecurrenceRule(_recurrenceRule: RecurrenceRule): void;
    /**
     */
    removeAllRecurrenceRules(): void;
    /**
     */
    save(): void;
    /**
     */
    remove(): void;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static scheduled(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static all(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allCompleted(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allIncomplete(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueToday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueToday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueToday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueTomorrow(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueTomorrow(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueTomorrow(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueYesterday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueYesterday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueYesterday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueThisWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueThisWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueThisWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueNextWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueNextWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueNextWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueLastWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueLastWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueLastWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedToday(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedThisWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedLastWeek(_calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param startDate Date
     * @param endDate Date
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static allDueBetween(_startDate: Date, _endDate: Date, _calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param startDate Date
     * @param endDate Date
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedDueBetween(_startDate: Date, _endDate: Date, _calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param startDate Date
     * @param endDate Date
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static incompleteDueBetween(_startDate: Date, _endDate: Date, _calendars?: readonly Calendar[]): Promise<Reminder[]>;
    /**
     * @param startDate Date
     * @param endDate Date
     * @param calendars readonly Calendar[]
     * @returns {Promise<Reminder[]>}
     */
    static completedBetween(_startDate: Date, _endDate: Date, _calendars?: readonly Calendar[]): Promise<Reminder[]>;
}
/**
 * Implementation class for Request
 */
declare class AbsRequest extends ScriptableObject implements Partial<Request> {
    static __className: string;
    /**
     * _URL to send request to._
     */
    get url(): string;
    set url(value: string);
    /**
     * _HTTP method used for the request._
     *
     * Specifies the HTTP method to use when sending the request. The default is to send the request using the GET HTTP method.
     */
    get method(): string;
    set method(value: string);
    /**
     * _HTTP headers to send with the request._
     *
     * Key value pairs where the key is the name of an HTTP header and the value will be sent as the value for the HTTP header.
     *
     * @type {{ [key: string]: string }}
     */
    get headers(): {
        [key: string]: string;
    };
    set headers(value: {
        [key: string]: string;
    });
    /**
     * _Body to send with the request._
     *
     * The body will be send along the request. While this property can be any value, currently only strings and Data is supported.
     *
     * Be aware that this property is ignored if you convert the request to a multipart request using `addParameterToMultipart`, `addFileToMultipart` or `addFileDataToMultipart`.
     */
    get body(): any;
    set body(value: any);
    /**
     * _Timeout interval of the request._
     *
     * If a request remains idle for longer than the timeout interval, the request is considered timed out.
     *
     * The timeout interval is measured in seconds and defaults to 60 seconds.
     */
    get timeoutInterval(): number;
    set timeoutInterval(value: number);
    /**
     * _Response of the request._
     *
     * The response is not populated until the request has been completed. The response is an object that looks like the following example.
     *
     * {
     * "url": "https://example.com/",
     * "statusCode": 200
     * "mimeType": "application/json",
     * "textEncodingName": "utf-8",
     * "headers": {
     * "Content-Type": "application/json;charset=utf-8",
     * "Content-Length": "17671"
     * },
     * "cookies": [{
     * "path": "/",
     * "httpOnly": true,
     * "domain": "www.example.com",
     * "sessionOnly": true,
     * "name": "JSESSIONID",
     * "value": "7616271F4878CFD05182D20C45F4CEB3"
     * }]
     * }
     *
     * @type {{ [key: string]: any }}
     */
    get response(): {
        [key: string]: any;
    };
    set response(value: {
        [key: string]: any;
    });
    /**
     * _Allow the request even if it is deemed insecure._
     *
     * By default Scriptable will attempt to reject requests that are deemed insecure.
     *
     * As an example, Scriptable will reject communicating with a server that has an invalid certificate. Such servers might be malicious and may put confidentional information at risk.
     * By enabling this setting, those requests will be allowed.
     *
     * Enable this setting at your own risk.
     */
    get allowInsecureRequest(): boolean;
    set allowInsecureRequest(value: boolean);
    /**
     * _Function called upon redirect._
     *
     * The function determines how redirects should be handled. By default redirects are allowed. When invoked the function is supplied with the request that we're about to redirect to.
     * The function can return the request to continue redirecting or it can return another request to redirect to. Returning null will stop the redirect. Note that onRedirect will only
     * be invoked on the initial request. Consecutive redirects should be handled on the initial request.
     *
     * @type {(arg0: Request) => Request}
     */
    get onRedirect(): (arg0: Request) => Request;
    set onRedirect(value: (arg0: Request) => Request);
    /**
     * @returns {Promise<Data>}
     */
    load(): Promise<Data>;
    /**
     * @returns {Promise<string>}
     */
    loadString(): Promise<string>;
    /**
     * @returns {Promise<any>}
     */
    loadJSON(): Promise<any>;
    /**
     * @returns {Promise<Image>}
     */
    loadImage(): Promise<Image>;
    /**
     * @param name string
     * @param value string
     */
    addParameterToMultipart(_name: string, _value: string): void;
    /**
     * @param data Data
     * @param mimeType string
     * @param name string
     * @param filename string
     */
    addFileDataToMultipart(_data: Data, _mimeType: string, _name: string, _filename: string): void;
    /**
     * @param filePath string
     * @param name string
     * @param filename string
     */
    addFileToMultipart(_filePath: string, _name: string, _filename?: string): void;
    /**
     * @param image Image
     * @param name string
     * @param filename string
     */
    addImageToMultipart(_image: Image, _name: string, _filename?: string): void;
}
/**
 * Implementation class for SFSymbol
 */
declare class AbsSFSymbol extends ScriptableObject implements Partial<SFSymbol> {
    static __className: string;
    /**
     * _Convert the symbol to an image._
     */
    get image(): Image;
    set image(value: Image);
    /**
     * @param font Font
     */
    applyFont(_font: Font): void;
    /**
     */
    applyUltraLightWeight(): void;
    /**
     */
    applyThinWeight(): void;
    /**
     */
    applyLightWeight(): void;
    /**
     */
    applyRegularWeight(): void;
    /**
     */
    applyMediumWeight(): void;
    /**
     */
    applySemiboldWeight(): void;
    /**
     */
    applyBoldWeight(): void;
    /**
     */
    applyHeavyWeight(): void;
    /**
     */
    applyBlackWeight(): void;
    /**
     * @param symbolName string
     * @returns {SFSymbol}
     */
    static named(_symbolName: string): SFSymbol;
}
/**
 * Implementation class for Size
 */
declare class AbsSize extends ScriptableObject implements Partial<Size> {
    static __className: string;
    /**
     * _Width value._
     */
    get width(): number;
    set width(value: number);
    /**
     * _Height value._
     */
    get height(): number;
    set height(value: number);
}
/**
 * Implementation class for TextField
 */
declare class AbsTextField extends ScriptableObject implements Partial<TextField> {
    static __className: string;
    /**
     * _Text in the text field._
     */
    get text(): string;
    set text(value: string);
    /**
     * _Placeholder shown in the text field while it is empty._
     */
    get placeholder(): string;
    set placeholder(value: string);
    /**
     * _Hides the text that is entered when set to true._
     *
     * The default value is false.
     */
    get isSecure(): boolean;
    set isSecure(value: boolean);
    /**
     * _Color of the text._
     */
    get textColor(): Color;
    set textColor(value: Color);
    /**
     * _Font of the text._
     */
    get font(): Font;
    set font(value: Font);
    /**
     */
    setDefaultKeyboard(): void;
    /**
     */
    setNumberPadKeyboard(): void;
    /**
     */
    setDecimalPadKeyboard(): void;
    /**
     */
    setNumbersAndPunctuationKeyboard(): void;
    /**
     */
    setPhonePadKeyboard(): void;
    /**
     */
    setWebSearchKeyboard(): void;
    /**
     */
    setEmailAddressKeyboard(): void;
    /**
     */
    setURLKeyboard(): void;
    /**
     */
    setTwitterKeyboard(): void;
    /**
     */
    leftAlignText(): void;
    /**
     */
    centerAlignText(): void;
    /**
     */
    rightAlignText(): void;
}
/**
 * Implementation class for Timer
 */
declare class AbsTimer extends ScriptableObject implements Partial<Timer> {
    static __className: string;
    /**
     * _The frequency at which the timer fires, in milliseconds._
     *
     * Be aware that the time interval is specified in setting. Defaults to 0, causing the timer to fire instantly.
     */
    get timeInterval(): number;
    set timeInterval(value: number);
    /**
     * _Whether the timer should repeat._
     *
     * A repeating timer will keep firing until it is invalidated. In contrast to non-repeating timers, repeating timers are not automatically invalidated. Defaults to false.
     */
    get repeats(): boolean;
    set repeats(value: boolean);
    /**
     * @param callback () => void
     */
    schedule(_callback: () => void): void;
    /**
     */
    invalidate(): void;
    /**
     * @param timeInterval number
     * @param repeats boolean
     * @param callback () => void
     * @returns {Timer}
     */
    static schedule(_timeInterval: number, _repeats: boolean, _callback: () => void): Timer;
}
/**
 * Implementation class for UITable
 */
declare class AbsUITable extends ScriptableObject implements Partial<UITable> {
    static __className: string;
    /**
     * _Whether to show separators._
     *
     * Whether to show separators between rows. Defaults to false.
     */
    get showSeparators(): boolean;
    set showSeparators(value: boolean);
    /**
     * @param row UITableRow
     */
    addRow(_row: UITableRow): void;
    /**
     * @param row UITableRow
     */
    removeRow(_row: UITableRow): void;
    /**
     */
    removeAllRows(): void;
    /**
     */
    reload(): void;
    /**
     * @param fullscreen boolean
     * @returns {Promise<void>}
     */
    present(_fullscreen?: boolean): Promise<void>;
}
/**
 * Implementation class for UITableCell
 */
declare class AbsUITableCell extends ScriptableObject implements Partial<UITableCell> {
    static __className: string;
    /**
     * _Relative width of the cell._
     *
     * A width weight specifies the relative width of the cell. When computing the absolute width of the cell, all width weights are taken into account. Consider the following example.
     *
     * Cell A has a width weight of 50. Cell B has a width weight of 100. Cell C has a width wegiht of 150.
     *
     * Assume that the row has an absolute width of 100. The width will be distributed among cells A, B and C. B will be double as wide as A but C will be fifty percent wider than B and
     * three times as wide as A.
     */
    get widthWeight(): number;
    set widthWeight(value: number);
    /**
     * _Whether to dismiss the table when the button is tapped._
     *
     * Defaults to false.
     */
    get dismissOnTap(): boolean;
    set dismissOnTap(value: boolean);
    /**
     * _Color of the title._
     *
     * This only has an effect on cells with a title. By default the color is null, in which case an appropriate color is automatically chosen based on the theme of the app and the
     * context the script is running in.
     */
    get titleColor(): Color;
    set titleColor(value: Color);
    /**
     * _Color of the subtitle._
     *
     * This only has an effect on cells with a subtitle. By default the color is null, in which case an appropriate color is automatically chosen based on the theme of the app and the
     * context the script is running in.
     */
    get subtitleColor(): Color;
    set subtitleColor(value: Color);
    /**
     * _Font of the title._
     */
    get titleFont(): Font;
    set titleFont(value: Font);
    /**
     * _Font of the subtitle._
     */
    get subtitleFont(): Font;
    set subtitleFont(value: Font);
    /**
     * _Called when the button is tapped._
     *
     * Buttons cannot be tapped when the table is presented in Siri.
     *
     * @type {() => void}
     */
    get onTap(): () => void;
    set onTap(value: () => void);
    /**
     */
    leftAligned(): void;
    /**
     */
    centerAligned(): void;
    /**
     */
    rightAligned(): void;
    /**
     * @param title string
     * @param subtitle string
     * @returns {UITableCell}
     */
    static text(_title?: string, _subtitle?: string): UITableCell;
    /**
     * @param image Image
     * @returns {UITableCell}
     */
    static image(_image: Image): UITableCell;
    /**
     * @param url string
     * @returns {UITableCell}
     */
    static imageAtURL(_url: string): UITableCell;
    /**
     * @param title string
     * @returns {UITableCell}
     */
    static button(_title: string): UITableCell;
}
/**
 * Implementation class for UITableRow
 */
declare class AbsUITableRow extends ScriptableObject implements Partial<UITableRow> {
    static __className: string;
    /**
     * _Spacing between cells._
     *
     * Specifies the horizontal spacing between cells in the row.
     */
    get cellSpacing(): number;
    set cellSpacing(value: number);
    /**
     * _Height of the row._
     *
     * The height of the row defaults to 44.
     */
    get height(): number;
    set height(value: number);
    /**
     * _Whether the cell is a header._
     *
     * Headers are highlighted cells that helps users understand context. Defaults to false.
     */
    get isHeader(): boolean;
    set isHeader(value: boolean);
    /**
     * _Whether to dismiss the table when the row is selected._
     *
     * This property will only have an effect if the row is selectable, i.e. `onSelect` has a value. Otherwise it is ignored.
     *
     * Defaults to true.
     */
    get dismissOnSelect(): boolean;
    set dismissOnSelect(value: boolean);
    /**
     * _Background color._
     */
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    /**
     * _Called when the row is selected._
     *
     * Called when the row is selected when the table is presented. If this has no value, the row cannot be selected. Defaults to null.
     *
     * Rows cannot be tapped when the tables is presented in Siri.
     *
     * @type {() => void}
     */
    get onSelect(): () => void;
    set onSelect(value: () => void);
    /**
     * @param cell UITableCell
     */
    addCell(_cell: UITableCell): void;
    /**
     * @param title string
     * @param subtitle string
     * @returns {UITableCell}
     */
    addText(_title?: string, _subtitle?: string): UITableCell;
    /**
     * @param image Image
     * @returns {UITableCell}
     */
    addImage(_image: Image): UITableCell;
    /**
     * @param url string
     * @returns {UITableCell}
     */
    addImageAtURL(_url: string): UITableCell;
    /**
     * @param title string
     * @returns {UITableCell}
     */
    addButton(_title: string): UITableCell;
}
/**
 * Implementation class for WebView
 */
declare class AbsWebView extends ScriptableObject implements Partial<WebView> {
    static __className: string;
    /**
     * _Function called upon load of a request._
     *
     * When the web view performs a request to load a resource, the function can determine whether or not to allow the request. Disallowing request can speed up the time it takes to load
     * the website. Requests made from JavaScript in the page are not passed to this function.
     *
     * By default all requests are allowed.
     *
     * @type {(arg0: Request) => boolean}
     */
    get shouldAllowRequest(): (arg0: Request) => boolean;
    set shouldAllowRequest(value: (arg0: Request) => boolean);
    /**
     * @param url string
     * @returns {Promise<void>}
     */
    loadURL(_url: string): Promise<void>;
    /**
     * @param request Request
     * @returns {Promise<void>}
     */
    loadRequest(_request: Request): Promise<void>;
    /**
     * @param html string
     * @param baseURL string
     * @returns {Promise<void>}
     */
    loadHTML(_html: string, _baseURL?: string): Promise<void>;
    /**
     * @param fileURL string
     * @returns {Promise<void>}
     */
    loadFile(_fileURL: string): Promise<void>;
    /**
     * @param javaScript string
     * @param useCallback boolean
     * @returns {Promise<any>}
     */
    evaluateJavaScript(_javaScript: string, _useCallback?: boolean): Promise<any>;
    /**
     * @returns {Promise<any>}
     */
    getHTML(): Promise<any>;
    /**
     * @param fullscreen boolean
     * @returns {Promise<void>}
     */
    present(_fullscreen?: boolean): Promise<void>;
    /**
     * @returns {Promise<any>}
     */
    waitForLoad(): Promise<any>;
    /**
     * @param html string
     * @param baseURL string
     * @param preferredSize Size
     * @param fullscreen boolean
     * @returns {Promise<void>}
     */
    static loadHTML(_html: string, _baseURL?: string, _preferredSize?: Size, _fullscreen?: boolean): Promise<void>;
    /**
     * @param fileURL string
     * @param preferredSize Size
     * @param fullscreen boolean
     * @returns {Promise<void>}
     */
    static loadFile(_fileURL: string, _preferredSize?: Size, _fullscreen?: boolean): Promise<void>;
    /**
     * @param url string
     * @param preferredSize Size
     * @param fullscreen boolean
     * @returns {Promise<void>}
     */
    static loadURL(_url: string, _preferredSize?: Size, _fullscreen?: boolean): Promise<void>;
}
/**
 * Implementation class for WidgetDate
 */
declare class AbsWidgetDate extends ScriptableObject implements Partial<WidgetDate> {
    static __className: string;
    /**
     * _Date to show in a widget._
     */
    get date(): Date;
    set date(value: Date);
    /**
     * _Color of the text._
     */
    get textColor(): Color;
    set textColor(value: Color);
    /**
     * _Font and text size of the text._
     */
    get font(): Font;
    set font(value: Font);
    /**
     * _Opacity of the text._
     *
     * Opacity of the text. This must be a value between 0 and 1. Defaults to 1.
     */
    get textOpacity(): number;
    set textOpacity(value: number);
    /**
     * _Maximum number of lines._
     *
     * Maximum number of lines to display. The limit is disabled when the value is 0 or less. Defaults to 0.
     */
    get lineLimit(): number;
    set lineLimit(value: number);
    /**
     * _Minimum amount the text scales down to._
     *
     * Sets the minimum amount that text scales down to fit in the available space. For example, a text with a minimum scale factor of 0.5 allows the widget to draw the text in a font
     * size half the size of the actual font. The scale factor should be a fraction between 0 and 1, both inclusive. Defaults to 1.
     */
    get minimumScaleFactor(): number;
    set minimumScaleFactor(value: number);
    /**
     * _Color of the shadow._
     *
     * Sets the color of the shadow cast by the text. The `shadowRadius` property must have a value greater than zero for this property to have an effect. Defaults to black.
     */
    get shadowColor(): Color;
    set shadowColor(value: Color);
    /**
     * _Size of the shadow._
     *
     * Sets the size of the shadow cast by the text. Defaults to 0.
     */
    get shadowRadius(): number;
    set shadowRadius(value: number);
    /**
     * _Offset of the shadow._
     *
     * Sets the offset of the shadow cast by the text. The `shadowRadius` property must have a value greater than zero for this property to have an effect. Defaults to (0, 0).
     */
    get shadowOffset(): Point;
    set shadowOffset(value: Point);
    /**
     * _URL to open._
     *
     * The URL will be opened when the text is tapped. This is only supported in medium and large widgets. Small widgets can only have a single tap target, which is specified by the `url`
     * property in the widget configurator.
     */
    get url(): string;
    set url(value: string);
    /**
     */
    leftAlignText(): void;
    /**
     */
    centerAlignText(): void;
    /**
     */
    rightAlignText(): void;
    /**
     */
    applyTimeStyle(): void;
    /**
     */
    applyDateStyle(): void;
    /**
     */
    applyRelativeStyle(): void;
    /**
     */
    applyOffsetStyle(): void;
    /**
     */
    applyTimerStyle(): void;
}
/**
 * Implementation class for WidgetImage
 */
declare class AbsWidgetImage extends ScriptableObject implements Partial<WidgetImage> {
    static __className: string;
    /**
     * _Image to show in widget._
     */
    get image(): Image;
    set image(value: Image);
    /**
     * _Whether the image is resizable._
     *
     * When set to true, the image can be resized. Defaults to true.
     */
    get resizable(): boolean;
    set resizable(value: boolean);
    /**
     * _Size of the image in the widget._
     *
     * Size of the image. When set to null, the image will be shwon at its full size. Defaults to null.
     */
    get imageSize(): Size;
    set imageSize(value: Size);
    /**
     * _Opacity when shown in widget._
     *
     * Opacity of the image. This must be a value between 0 and 1. Defaults to 1.
     */
    get imageOpacity(): number;
    set imageOpacity(value: number);
    /**
     * _Radius of the corners._
     *
     * Radius of the rounded corners. This property is ignored when `containerRelativeShape` is set to true. Defaults to 0.
     */
    get cornerRadius(): number;
    set cornerRadius(value: number);
    /**
     * _Border width._
     *
     * Width of the border around the image. Defaults to 0.
     */
    get borderWidth(): number;
    set borderWidth(value: number);
    /**
     * _Border color._
     *
     * Color of the border around the image. Defaults to black.
     */
    get borderColor(): Color;
    set borderColor(value: Color);
    /**
     * _Shape the image relative to its container._
     *
     * When true the corners of the image will be rounded relative to the containing widget. The value of `cornerRadius` is ignored when this is true. Defaults to false.
     */
    get containerRelativeShape(): boolean;
    set containerRelativeShape(value: boolean);
    /**
     * _Tint color of the image._
     *
     * Changes the color of the image. Set to `null` to show the original image. Defaults to `null`.
     */
    get tintColor(): Color;
    set tintColor(value: Color);
    /**
     * _URL to open._
     *
     * The URL will be opened when the image is tapped. This is only supported in medium and large widgets. Small widgets can only have a single tap target, which is specified by the `url`
     * on the widget.
     */
    get url(): string;
    set url(value: string);
    /**
     */
    leftAlignImage(): void;
    /**
     */
    centerAlignImage(): void;
    /**
     */
    rightAlignImage(): void;
    /**
     */
    applyFittingContentMode(): void;
    /**
     */
    applyFillingContentMode(): void;
}
/**
 * Implementation class for WidgetSpacer
 */
declare class AbsWidgetSpacer extends ScriptableObject implements Partial<WidgetSpacer> {
    static __className: string;
    /**
     * _Amount of space this spacer consumes._
     */
    get length(): number;
    set length(value: number);
}
/**
 * Implementation class for WidgetStack
 */
declare class AbsWidgetStack extends ScriptableObject implements Partial<WidgetStack> {
    static __className: string;
    /**
     * _Background color of the stack._
     */
    get backgroundColor(): Color;
    set backgroundColor(value: Color);
    /**
     * _Background image._
     */
    get backgroundImage(): Image;
    set backgroundImage(value: Image);
    /**
     * _Background gradient._
     */
    get backgroundGradient(): LinearGradient;
    set backgroundGradient(value: LinearGradient);
    /**
     * _Spacing between elements._
     *
     * Specifies the spacing between elements in the stack. You can also use the `addSpacer()` function on the widget to add spacing between elements. Defaults to 0.
     */
    get spacing(): number;
    set spacing(value: number);
    /**
     * _Size of the stack._
     *
     * Specifies the size of the stack when shown in a widget. When a dimension is set to zero or less, the widget will automatically decide a length for that dimension. Both dimensions
     * default to 0.
     */
    get size(): Size;
    set size(value: Size);
    /**
     * _Radius of the corners._
     *
     * Radius of the rounded corners. Defaults to 0.
     */
    get cornerRadius(): number;
    set cornerRadius(value: number);
    /**
     * _Border width._
     *
     * Width of the border around the stack. Defaults to 0.
     */
    get borderWidth(): number;
    set borderWidth(value: number);
    /**
     * _Border color._
     *
     * Color of the border around the stack. Defaults to black.
     */
    get borderColor(): Color;
    set borderColor(value: Color);
    /**
     * _URL to open._
     *
     * The URL will be opened when the stack is tapped. This is only supported in medium and large widgets. Small widgets can only have a single tap target, which is specified by the `url`
     * property in the widget configurator.
     */
    get url(): string;
    set url(value: string);
    /**
     * @param text string
     * @returns {WidgetText}
     */
    addText(_text: string): WidgetText;
    /**
     * @param date Date
     * @returns {WidgetDate}
     */
    addDate(_date: Date): WidgetDate;
    /**
     * @param image Image
     * @returns {WidgetImage}
     */
    addImage(_image: Image): WidgetImage;
    /**
     * @param length number
     * @returns {WidgetSpacer}
     */
    addSpacer(_length?: number): WidgetSpacer;
    /**
     * @returns {WidgetStack}
     */
    addStack(): WidgetStack;
    /**
     * @param top number
     * @param leading number
     * @param bottom number
     * @param trailing number
     */
    setPadding(_top: number, _leading: number, _bottom: number, _trailing: number): void;
    /**
     */
    useDefaultPadding(): void;
    /**
     */
    topAlignContent(): void;
    /**
     */
    centerAlignContent(): void;
    /**
     */
    bottomAlignContent(): void;
    /**
     */
    layoutHorizontally(): void;
    /**
     */
    layoutVertically(): void;
}
/**
 * Implementation class for WidgetText
 */
declare class AbsWidgetText extends ScriptableObject implements Partial<WidgetText> {
    static __className: string;
    /**
     * _Text to show in a widget._
     */
    get text(): string;
    set text(value: string);
    /**
     * _Color of the text._
     */
    get textColor(): Color;
    set textColor(value: Color);
    /**
     * _Font and text size of the text._
     */
    get font(): Font;
    set font(value: Font);
    /**
     * _Opacity of the text._
     *
     * Opacity of the text. This must be a value between 0 and 1. Defaults to 1.
     */
    get textOpacity(): number;
    set textOpacity(value: number);
    /**
     * _Maximum number of lines._
     *
     * Maximum number of lines to display. The limit is disabled when the value is 0 or less. Defaults to 0.
     */
    get lineLimit(): number;
    set lineLimit(value: number);
    /**
     * _Minimum amount the text scales down to._
     *
     * Sets the minimum amount that text scales down to fit in the available space. For example, a text with a minimum scale factor of 0.5 allows the widget to draw the text in a font
     * size half the size of the actual font. The scale factor should be a fraction between 0 and 1, both inclusive. Defaults to 1.
     */
    get minimumScaleFactor(): number;
    set minimumScaleFactor(value: number);
    /**
     * _Color of the shadow._
     *
     * Sets the color of the shadow cast by the text. The `shadowRadius` property must have a value greater than zero for this property to have an effect. Defaults to black.
     */
    get shadowColor(): Color;
    set shadowColor(value: Color);
    /**
     * _Size of the shadow._
     *
     * Sets the size of the shadow cast by the text. Defaults to 0.
     */
    get shadowRadius(): number;
    set shadowRadius(value: number);
    /**
     * _Offset of the shadow._
     *
     * Sets the offset of the shadow cast by the text. The `shadowRadius` property must have a value greater than zero for this property to have an effect. Defaults to (0, 0).
     */
    get shadowOffset(): Point;
    set shadowOffset(value: Point);
    /**
     * _URL to open._
     *
     * The URL will be opened when the text is tapped. This is only supported in medium and large widgets. Small widgets can only have a single tap target, which is specified by the `url`
     * property in the widget configurator.
     */
    get url(): string;
    set url(value: string);
    /**
     */
    leftAlignText(): void;
    /**
     */
    centerAlignText(): void;
    /**
     */
    rightAlignText(): void;
}
/**
 * Implementation class for XMLParser
 */
declare class AbsXMLParser extends ScriptableObject implements Partial<XMLParser> {
    static __className: string;
    /**
     * _XML string to be parsed._
     */
    get string(): string;
    set string(value: string);
    /**
     * _Function called when the parser begins parsing a document._
     *
     * @type {() => void}
     */
    get didStartDocument(): () => void;
    set didStartDocument(value: () => void);
    /**
     * _Function called when the parser ends parsing a document._
     *
     * When the parser calls the function, it has successfully completed parsing the document.
     *
     * @type {() => void}
     */
    get didEndDocument(): () => void;
    set didEndDocument(value: () => void);
    /**
     * _Function called when starting to parse an element._
     *
     * Called by the parser when it encounters a start tag for an element. The function takes the element name as a parameter as well as a key value pair containing all the attributes
     * associated with the element.
     *
     * Use this function to update your state and prepare for receiving the characters of the element. After this function is called, the parser will call the foundCharacters callback
     * function with all or parts of the characters of the element.
     *
     * @type {(arg0: string, arg1: { [key: string]: string }) => void}
     */
    get didStartElement(): (arg0: string, arg1: {
        [key: string]: string;
    }) => void;
    set didStartElement(value: (arg0: string, arg1: {
        [key: string]: string;
    }) => void);
    /**
     * _Function called when ended parsing an element._
     *
     * Called by the parser when it encounters an end tag for an element. The function takes the element name as a parameter.
     *
     * @type {(name: string) => void}
     */
    get didEndElement(): (name: string) => void;
    set didEndElement(value: (name: string) => void);
    /**
     * _Function called when the parser finds characters of an element._
     *
     * The parser calls this function with a string whenever it finds characters for the current element. This function may be called several times for a single element.
     *
     * @type {(str: string) => void}
     */
    get foundCharacters(): (str: string) => void;
    set foundCharacters(value: (str: string) => void);
    /**
     * _Function called when the parser encounters an error._
     *
     * The parser will call this function when it encounters a fatal error preventing it from continuing to parse. When the function is called the parsing is stopped.
     *
     * @type {(error: string) => void}
     */
    get parseErrorOccurred(): (error: string) => void;
    set parseErrorOccurred(value: (error: string) => void);
    /**
     * @returns {boolean}
     */
    parse(): boolean;
}
/** Type definition for global variable `args` */
type IArgs = typeof args;
/** Type definition for global variable `config` */
type IConfig = typeof config;
/** Type definition for global variable `console` */
type IConsole = typeof console;
/** Type definition for global variable `Device` */
type IDevice = typeof Device;
/** Type definition for global variable `Dictation` */
type IDictation = typeof Dictation;
/** Type definition for global variable `DocumentPicker` */
type IDocumentPicker = typeof DocumentPicker;
/** Type definition for global variable `Keychain` */
type IKeychain = typeof Keychain;
/** Type definition for global variable `Location` */
type ILocation = typeof Location;
/** Type definition for global variable `module` */
type IModule = typeof module;
/** Type definition for global variable `Pasteboard` */
type IPasteboard = typeof Pasteboard;
/** Type definition for global variable `Photos` */
type IPhotos = typeof Photos;
/** Type definition for global variable `QuickLook` */
type IQuickLook = typeof QuickLook;
/** Type definition for global variable `Safari` */
type ISafari = typeof Safari;
/** Type definition for global variable `Script` */
type IScript = typeof Script;
/** Type definition for global variable `ShareSheet` */
type IShareSheet = typeof ShareSheet;
/** Type definition for global variable `Speech` */
type ISpeech = typeof Speech;
/** Type definition for global variable `URLScheme` */
type IURLScheme = typeof URLScheme;
/** Type definition for global variable `UUID` */
type IUUID = typeof UUID;

export { AbsAlert, AbsCalendar, AbsCalendarEvent, AbsCallbackURL, AbsColor, AbsContact, AbsContactsContainer, AbsContactsGroup, AbsData, AbsDateFormatter, AbsDatePicker, AbsDrawContext, AbsFileManager, AbsFont, AbsImage, AbsLinearGradient, AbsListWidget, AbsMail, AbsMessage, AbsNotification, AbsPath, AbsPoint, AbsRect, AbsRecurrenceRule, AbsRelativeDateTimeFormatter, AbsReminder, AbsRequest, AbsSFSymbol, AbsSize, AbsTextField, AbsTimer, AbsUITable, AbsUITableCell, AbsUITableRow, AbsWebView, AbsWidgetDate, AbsWidgetImage, AbsWidgetSpacer, AbsWidgetStack, AbsWidgetText, AbsXMLParser, type IArgs, type IConfig, type IConsole, type IDevice, type IDictation, type IDocumentPicker, type IKeychain, type ILocation, type IModule, type IPasteboard, type IPhotos, type IQuickLook, type ISafari, type IScript, type IShareSheet, type ISpeech, type IURLScheme, type IUUID, ScriptableObject };
